Learn R Programming

mvLSWimpute (version 0.1.1)

mvLSWimpute-package: tools:::Rd_package_title("mvLSWimpute")

Description

tools:::Rd_package_description("mvLSWimpute")

Arguments

Author

tools:::Rd_package_author("mvLSWimpute")

Maintainer: tools:::Rd_package_maintainer("mvLSWimpute")

Details

The DESCRIPTION file: tools:::Rd_package_DESCRIPTION("mvLSWimpute") tools:::Rd_package_indices("mvLSWimpute")

The main routine of the package is mv_impute which performs forward or forward and backward imputation of locally stationary multivariate time series, using one-step ahead forecasting (and backcasting).

References

Wilson, R. E., Eckley, I. A., Nunes, M. A. and Park, T. (2021) A wavelet-based approach for imputation in nonstationary multivariate time series. _Statistics and Computing_ *31* Article 18, doi:10.1007/s11222-021-09998-2.